use std::fmt::Display;

#[derive(Default)]
pub enum APIVersion {
    #[default]
    V1,
}

impl Display for APIVersion {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::V1 => write!(f, "v1"),
        }
    }
}

#[derive(Default, Debug, serde::Deserialize)]
pub enum Order {
    Ascending,
    #[default]
    Descending,
}

impl Display for Order {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::Ascending => write!(f, "RELEASE_DATE_ASC"),
            Self::Descending => write!(f, "RELEASE_DATE_DESC"),
        }
    }
}

#[derive(Debug, serde::Deserialize)]
#[serde(rename_all = "SCREAMING_SNAKE_CASE")]
pub enum Stream {
    #[serde(rename = "LTS")]
    LTS,
    Beta,
    Alpha,
    Tech,
}

impl Display for Stream {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::LTS => write!(f, "LTS"),
            Self::Beta => write!(f, "BETA"),
            Self::Alpha => write!(f, "ALPHA"),
            Self::Tech => write!(f, "TECH"),
        }
    }
}

#[derive(Debug, serde::Deserialize)]
#[serde(rename_all = "SCREAMING_SNAKE_CASE")]
pub enum Platform {
    Windows,
    Linux,
    #[serde(rename = "MAC_OS")]
    MacOS,
}

impl Display for Platform {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::Windows => write!(f, "WINDOWS"),
            Self::Linux => write!(f, "LINUX"),
            Self::MacOS => write!(f, "MAC_OS"),
        }
    }
}

#[derive(Debug, serde::Deserialize)]
#[serde(rename_all = "SCREAMING_SNAKE_CASE")]
pub enum Architecture {
    X86_64,
    Arm64,
}

impl Display for Architecture {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::Arm64 => write!(f, "ARM64"),
            Self::X86_64 => write!(f, "X86_64"),
        }
    }
}

#[derive(Debug, serde::Deserialize)]
pub struct Version(pub String);
